@@ -511,7 +511,7 @@ pReturns <- function(x, t, period, complete.first = TRUE,
     ans
 }
 
-as.zoo.p_returns <- function (x, ...) {
+as.zoo.p_returns <- function(x, ...) {
     zoo(x, order.by = attr(x, "t"), ...)
 }
 
@@ -582,6 +582,15 @@ print.p_returns <- function(x, ..., year.rows = TRUE,
     period <- attr(x, "period")
     timestamp <- attr(x, "t")
     instr <- names(x)
+
+    if (inherits(timestamp, "yearmon")) {
+        units_per_year <- 1
+    } else if (inherits(timestamp, "yearqtr")) {
+        units_per_year <- 1
+    } else {
+        units_per_year <- 365
+    }
+
     if (identical(period, "yearly") && is.null(dim(x))) {
         tmp <- x
         names(tmp) <- format(timestamp, "%Y")
@@ -622,10 +631,10 @@ print.p_returns <- function(x, ..., year.rows = TRUE,
         }
 
         note <- rep("]", length(x))
-        note[as.numeric(timestamp[, 2L] - timestamp[, 1L])/365 < 1 &
+        note[as.numeric(timestamp[, 2L] - timestamp[, 1L])/units_per_year < 1 &
               attr(x, "is.annualised")] <-
             "; less than one year, but annualised]"
-        note[as.numeric(timestamp[, 2L] - timestamp[, 1L])/365 < 1 &
+        note[as.numeric(timestamp[, 2L] - timestamp[, 1L])/units_per_year < 1 &
               !attr(x, "is.annualised")] <-
             "; less than one year, not annualised]"
         cat(paste0(nn, r_str, cal_str, note, collapse = "\n"), "\n")
@@ -788,9 +797,12 @@ toText.p_returns <- function(x, ..., year.rows = TRUE,
     mt <- rbind(colnames(mt), mt)
     mt <- cbind(rownames(mt), mt)
     mt <- unname(mt)
-    mt <- apply(mt, 2, function(x) {format(x,
-                                           width = max(5, nchar(x)),
-                                           justify = "right")})
+    mt <- apply(mt, 2,
+                function(x) {
+                    format(x,
+                           width = max(5, nchar(x)),
+                           justify = "right")
+    })
     mt <- apply(mt, 1, paste0, collapse = "")
     class(mt) <- "text"
     mt
